.. _whatsnew:

**********
What's New
**********

These are new features and improvements of note in each release.

.. toctree::
   :maxdepth: 2

   1.0.0rc3
   1.0.0rc2
   1.0.0rc1
   1.0.0b6
   1.0.0b5
   1.0.0b4
   1.0.0b3
   1.0.0b2
   1.0.0b1
   1.0.0a
